# Changelog

## [2.3.0a1](https://github.com/OpenVoiceOS/OVOS-workshop/tree/2.3.0a1) (2024-11-12)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/2.2.3...2.3.0a1)

**Implemented enhancements:**

- feat:  euphony [\#273](https://github.com/OpenVoiceOS/OVOS-workshop/issues/273)

**Merged pull requests:**

- feat:euphony [\#277](https://github.com/OpenVoiceOS/OVOS-workshop/pull/277) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
